/**
 * Bevat alle lidmaatschapdetails voor één club.
 * 
 * Voorlopig nemen we aan dat er hoogstens 100 leden
 * tot de club kunnen behoren.
 */
public class Club {
    
    private Lidmaatschap[] tab;
    
    private static final int MAX = 100;
    
    /**
     * Nieuwe club, zonder leden
     */
    public Club() {
        tab = new Lidmaatschap[MAX];
    }

    /**
     * Voeg een nieuw lidmaatschap toe
     */
    public void maakLid(Lidmaatschap lidmaatschap) {
        // zoek lege positie
        int pos = 0;
        while (pos < MAX && tab[pos] != null) {
            pos ++;
        }
        if (pos == MAX) {
            // signaleert een fout
            throw new IllegalArgumentException ("Geen toetreding meer mogelijk");      
        } else {
            tab[pos] = lidmaatschap;    
        }
    }
    
    
    
    /**
     * Voeg een nieuw lidmaatschap toe
     */
    public void maakLid(String naam, int maand, int jaar) {
        maakLid (new Lidmaatschap (naam, maand, jaar));
    }
     
    /**
     * Aantal leden
     */
    public int getAantalLeden() {
        int totaal = 0;
        for (Lidmaatschap lms : tab) {
            if (lms != null) {
                totaal ++;
            }
        }
        return totaal;
    }
    
    /**
     * Aantal leden ingeschreven in een bepaalde
     * maand en een bepaald jaar
     */
    public int getAantalLeden (int maand, int jaar) {
        int totaal = 0;
        for (Lidmaatschap lms : tab) {
            if (lms != null && 
                lms.getMaand() == maand && lms.getJaar() == jaar) {
                totaal ++;
            }
        }
        return totaal;
    }
    
    /**
     * Verwijder alle leden de zijn ingeschreven
     * in een bepaalde maand en een bepaald jaar
     */
    public void verwijderLeden (int maand, int jaar) {
        // kan niet met for each, want je hebt een index nodig
        for (int i=0; i < MAX; i++) {
            Lidmaatschap lms = tab[i];
            if (lms != null &&
                lms.getMaand() == maand && lms.getJaar() == jaar) {
                tab[i] = null;
            }
        }            
    }
    
}

